==> 1.0.0.tar.gz: android/src/main/java/com/rehan/yodosdk/Reward/YodoRewardHelper.java <==
package com.rehan.yodosdk.Reward;

import android.app.Activity;

import androidx.annotation.NonNull;

import com.yodo1.mas.error.Yodo1MasError;
import com.yodo1.mas.interstitial.Yodo1MasInterstitialAd;
import com.yodo1.mas.interstitial.Yodo1MasInterstitialAdListener;
import com.yodo1.mas.reward.Yodo1MasRewardAd;
import com.yodo1.mas.reward.Yodo1MasRewardAdListener;

import io.flutter.plugin.common.MethodChannel;

public class YodoRewardHelper {
    static MethodChannel methodChannel;

    public static void setMethodChannel(MethodChannel state) {
        methodChannel = state;
    }

    static Yodo1MasRewardAdListener yodo1MasRewardAdListener = new Yodo1MasRewardAdListener() {
        @Override
        public void onRewardAdLoaded(Yodo1MasRewardAd ad) {
            System.out.println("YodoAndroid::Reward::Loaded");
            methodChannel.invokeMethod("loaded_reward_inter", "");
        }

        @Override
        public void onRewardAdFailedToLoad(Yodo1MasRewardAd ad, @NonNull Yodo1MasError error) {
            System.out.println("YodoAndroid::Reward::FailedToLoad");
            System.out.println(error.getMessage());
            methodChannel.invokeMethod("fail_load_reward_inter", "error.getJsonObject()");
        }

        @Override
        public void onRewardAdOpened(Yodo1MasRewardAd ad) {
            System.out.println("YodoAndroid::Reward::Opened");
            methodChannel.invokeMethod("open_reward_inter", "");
        }

        @Override
        public void onRewardAdFailedToOpen(Yodo1MasRewardAd ad, @NonNull Yodo1MasError error) {
            System.out.println("YodoAndroid::Reward::FailedToOpen");
            methodChannel.invokeMethod("fail_open_reward_inter", error.getJsonObject());
        }

        @Override
        public void onRewardAdClosed(Yodo1MasRewardAd ad) {
            System.out.println("YodoAndroid::Reward::RewardAdClosed");
            methodChannel.invokeMethod("close_reward_inter", "");
        }

        @Override
        public void onRewardAdEarned(Yodo1MasRewardAd ad) {
            System.out.println("YodoAndroid::Reward::Earned");
            methodChannel.invokeMethod("rewarded_reward_inter", "");
        }
    };

    public static void setListener(Yodo1MasRewardAdListener state) {
        yodo1MasRewardAdListener = state;
    }

    public static void loadAndShowReward(Activity context) {
        Yodo1MasRewardAd.getInstance().setAdListener(yodo1MasRewardAdListener);
        boolean isLoaded = Yodo1MasRewardAd.getInstance().isLoaded();
        if (isLoaded) {
            Yodo1MasRewardAd.getInstance().showAd(context, "AndroidSdk");
        } else {
            Yodo1MasRewardAd.getInstance().loadAndShowAd(context, "AndroidSdk");
        }
    }

    public static void loadOnly(Activity context) {
        Yodo1MasRewardAd.getInstance().setAdListener(yodo1MasRewardAdListener);
        Yodo1MasRewardAd.getInstance().loadAd(context);
    }
}

==> 1.0.6.tar.gz: android/src/main/java/com/rehan/yodosdk/Reward/YodoRewardHelper.java <==
package com.rehan.yodosdk.Reward;

import android.app.Activity;

import androidx.annotation.NonNull;

import com.yodo1.mas.error.Yodo1MasError;
import com.yodo1.mas.interstitial.Yodo1MasInterstitialAd;
import com.yodo1.mas.interstitial.Yodo1MasInterstitialAdListener;
import com.yodo1.mas.reward.Yodo1MasRewardAd;
import com.yodo1.mas.reward.Yodo1MasRewardAdListener;

import io.flutter.plugin.common.MethodChannel;

public class YodoRewardHelper {
    static MethodChannel methodChannel;

    public static void setMethodChannel(MethodChannel state) {
        methodChannel = state;
    }

    static Yodo1MasRewardAdListener yodo1MasRewardAdListener = new Yodo1MasRewardAdListener() {
        @Override
        public void onRewardAdLoaded(Yodo1MasRewardAd ad) {
            System.out.println("YodoAndroid::Reward::Loaded");
            methodChannel.invokeMethod("loaded_reward", "");
        }

        @Override
        public void onRewardAdFailedToLoad(Yodo1MasRewardAd ad, @NonNull Yodo1MasError error) {
            System.out.println("YodoAndroid::Reward::FailedToLoad");
            System.out.println(error.getMessage());
            methodChannel.invokeMethod("fail_load_reward", "error.getJsonObject()");
        }

        @Override
        public void onRewardAdOpened(Yodo1MasRewardAd ad) {
            System.out.println("YodoAndroid::Reward::Opened");
            methodChannel.invokeMethod("open_reward", "");
        }

        @Override
        public void onRewardAdFailedToOpen(Yodo1MasRewardAd ad, @NonNull Yodo1MasError error) {
            System.out.println("YodoAndroid::Reward::FailedToOpen");
            methodChannel.invokeMethod("fail_open_reward", error.getJsonObject());
        }

        @Override
        public void onRewardAdClosed(Yodo1MasRewardAd ad) {
            System.out.println("YodoAndroid::Reward::RewardAdClosed");
            methodChannel.invokeMethod("close_reward", "");
        }

        @Override
        public void onRewardAdEarned(Yodo1MasRewardAd ad) {
            System.out.println("YodoAndroid::Reward::Earned");
            methodChannel.invokeMethod("rewarded_reward", "");
        }
    };

    public static void setListener(Yodo1MasRewardAdListener state) {
        yodo1MasRewardAdListener = state;
    }

    public static void loadAndShowReward(Activity context) {
        Yodo1MasRewardAd.getInstance().setAdListener(yodo1MasRewardAdListener);
        boolean isLoaded = Yodo1MasRewardAd.getInstance().isLoaded();
        if (isLoaded) {
            Yodo1MasRewardAd.getInstance().showAd(context, "AndroidSdk");
        } else {
            Yodo1MasRewardAd.getInstance().loadAndShowAd(context, "AndroidSdk");
        }
    }

    public static void loadOnly(Activity context) {
        Yodo1MasRewardAd.getInstance().setAdListener(yodo1MasRewardAdListener);
        Yodo1MasRewardAd.getInstance().loadAd(context);
    }
}
